@@ -13,6 +13,7 @@ Usage::
     client: CodeBuildClient = session.client("codebuild")
     ```
 """
+
 import sys
 from typing import Any, Dict, Mapping, Sequence, Type, overload
 
@@ -112,7 +113,7 @@ from .type_defs import (
     WebhookFilterTypeDef,
 )
 
-if sys.version_info >= (3, 9):
+if sys.version_info >= (3, 12):
     from typing import Literal
 else:
     from typing_extensions import Literal
@@ -121,7 +122,7 @@ else:
 __all__ = ("CodeBuildClient",)
 
 
-class BotocoreClientError(BaseException):
+class BotocoreClientError(Exception):
     MSG_TEMPLATE: str
 
     def __init__(self, error_response: Mapping[str, Any], operation_name: str) -> None:
@@ -278,8 +279,9 @@ class CodeBuildClient(BaseClient):
     ) -> CreateWebhookOutputTypeDef:
         """
         For an existing CodeBuild build project that has its source code stored in a
-        GitHub or Bitbucket repository, enables CodeBuild to start rebuilding the source
-        code every time a code change is pushed to the repository.
+        GitHub or Bitbucket repository, enables CodeBuild to start rebuilding the
+        source code every time a code change is pushed to the
+        repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.create_webhook)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#create_webhook)
@@ -337,7 +339,8 @@ class CodeBuildClient(BaseClient):
         """
         For an existing CodeBuild build project that has its source code stored in a
         GitHub or Bitbucket repository, stops CodeBuild from rebuilding the source code
-        every time a code change is pushed to the repository.
+        every time a code change is pushed to the
+        repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.delete_webhook)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#delete_webhook)
@@ -423,7 +426,8 @@ class CodeBuildClient(BaseClient):
     ) -> ImportSourceCredentialsOutputTypeDef:
         """
         Imports the source repository credentials for an CodeBuild project that has its
-        source code stored in a GitHub, GitHub Enterprise, or Bitbucket repository.
+        source code stored in a GitHub, GitHub Enterprise, or Bitbucket
+        repository.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.import_source_credentials)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#import_source_credentials)
@@ -483,7 +487,8 @@ class CodeBuildClient(BaseClient):
     ) -> ListBuildsForProjectOutputTypeDef:
         """
         Gets a list of build identifiers for the specified build project, with each
-        build identifier representing a single build.
+        build identifier representing a single
+        build.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.list_builds_for_project)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#list_builds_for_project)
@@ -506,7 +511,8 @@ class CodeBuildClient(BaseClient):
     ) -> ListProjectsOutputTypeDef:
         """
         Gets a list of build project names, with each build project name representing a
-        single build project.
+        single build
+        project.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.list_projects)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#list_projects)
@@ -554,7 +560,7 @@ class CodeBuildClient(BaseClient):
         filter: ReportFilterTypeDef = ...
     ) -> ListReportsForReportGroupOutputTypeDef:
         """
-        Returns a list of ARNs for the reports that belong to a `ReportGroup` .
+        Returns a list of ARNs for the reports that belong to a `ReportGroup`.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.list_reports_for_report_group)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#list_reports_for_report_group)
@@ -570,7 +576,8 @@ class CodeBuildClient(BaseClient):
     ) -> ListSharedProjectsOutputTypeDef:
         """
         Gets a list of projects that are shared with other Amazon Web Services accounts
-        or users.
+        or
+        users.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.list_shared_projects)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#list_shared_projects)
@@ -586,7 +593,8 @@ class CodeBuildClient(BaseClient):
     ) -> ListSharedReportGroupsOutputTypeDef:
         """
         Gets a list of report groups that are shared with other Amazon Web Services
-        accounts or users.
+        accounts or
+        users.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/codebuild.html#CodeBuild.Client.list_shared_report_groups)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_codebuild/client/#list_shared_report_groups)
